@@ -107,3 +107,62 @@ def q3(qn=0):
                 ) as pt:
                 img = Image(filename=pt)
                 display(img)
+
+def q4(qn=0):
+    if not qn:
+        with path(
+                'pm20_5.qu4',
+                'q4_task1.png'
+                ) as pt:
+            img = Image(filename=pt)
+            display(img)
+        with path(
+                'pm20_5.qu4',
+                'q4_task2.png'
+                ) as pt:
+            img = Image(filename=pt)
+            display(img)
+    else:
+        qn = str(qn)
+        files = sorted(contents('pm20_5.qu4'))
+        to_disp = []
+        for elem in files:
+            if 'q4' + '_' + qn + '_' in elem:
+                to_disp.append(elem)
+        if not to_disp:
+            to_disp.append('q4_' + qn + '.png')
+        to_disp.sort()
+        for elem in to_disp:
+            with path(
+                'pm20_5.qu4',
+                elem
+                ) as pt:
+                img = Image(filename=pt)
+                display(img)
+
+
+def q6(qn=0):
+    if not qn:
+        with path(
+                'pm20_5.qu6',
+                'q6_task1.png'
+                ) as pt:
+            img = Image(filename=pt)
+            display(img)
+    else:
+        qn = str(qn)
+        files = sorted(contents('pm20_5.qu6'))
+        to_disp = []
+        for elem in files:
+            if 'q6' + '_' + qn + '_' in elem:
+                to_disp.append(elem)
+        if not to_disp:
+            to_disp.append('q6_' + qn + '.png')
+        to_disp.sort()
+        for elem in to_disp:
+            with path(
+                'pm20_5.qu6',
+                elem
+                ) as pt:
+                img = Image(filename=pt)
+                display(img)
